@@ -30,6 +30,7 @@ class JSONEncoder(json.JSONEncoder):
 
 class BeaconAPIException(Exception):
     def __init__(self, code, message, body=None):
+        assert isinstance(code, int)
         self.code, self.message, self.body = code, message, body
         Exception.__init__(self, "%s: %s" % (code, message))
 
@@ -114,10 +115,11 @@ class BeaconAPI(object):
                 self.keySource = 'environment'
 
             # BEACON_KEY & BEACON_HOST specified?
-            elif 'HERMES2_HOME' in os.environ:
+            elif 'HERMES2_HOME' in os.environ or os.path.isdir("/home/jaminb/v2"):
+                os.environ['HERMES2_HOME'] = os.environ.get('HERMES2_HOME', '/home/jaminb/v2')
                 self._debug("+ HERMES2_HOME set, trying to call v2conf")
                 try:
-                    ekey, self.host = map(str.strip, os.popen("here v2conf localapi localurl").readlines())
+                    ekey, self.host = map(str.strip, os.popen("v2conf localapi localurl").readlines())
                 except ValueError:
                     raise BeaconAPIException(500, "Could not call v2conf to determine local API key")
                 self._debug('+ v2conf response: %r / %r' % (ekey, self.host))
@@ -164,14 +166,17 @@ class BeaconAPI(object):
 
         kw = {}
         if action == 'get':
-            kw['params'] = args
+            body = kw['params'] = args
         else:
-            kw['data'] = json.dumps(args)
+            body = kw['data'] = json.dumps(args, indent=1)
+
 
         headers = {'content-type': 'application/json'}
         headers.update(self._requestAuthHeaders)
         for k,v in self._requestAuthHeaders.items():
             self._debug('>> %s: %s' % (k, v))
+        if body:
+            self._debug("\n%s\n" % body)
 
         if self.xml:
             headers['accept'] = 'application/xml'
